@@ -1,11 +1,11 @@
-#  File R/control.utilities.R in package statnet.common, part of the
-#  Statnet suite of packages for network analysis, https://statnet.org .
+#  File R/control.utilities.R in package statnet.common, part of the Statnet
+#  suite of packages for network analysis, https://statnet.org .
 #
-#  This software is distributed under the GPL-3 license.  It is free,
-#  open source, and has the attribution requirements (GPL Section 7) at
+#  This software is distributed under the GPL-3 license.  It is free, open
+#  source, and has the attribution requirements (GPL Section 7) at
 #  https://statnet.org/attribution .
 #
-#  Copyright 2007-2023 Statnet Commons
+#  Copyright 2007-2025 Statnet Commons
 ################################################################################
 .autodetect_dep_warn <- local({
   warned <- c()
@@ -361,7 +361,8 @@ as.control.list.list <- function(x, FUN=NULL, unflat=TRUE, ...){
           l[aname] <- list(x[[aname]])
           xnames_unused <<- setdiff(xnames_unused, aname)
         }else if(is.call(aval <- args[[aname]]) && startsWith(as.character(aval[[1]]), "control.")){ # A control list not supplied directly: process recursively.
-          l[aname] <- list(unflat(get(as.character(aval[[1]]), pos=environment(f), mode="function")))
+          subargs <- unflat(get(as.character(aval[[1]]), pos=environment(f), mode="function"))
+          if(length(subargs)) l[aname] <- list(subargs)
         }
       # Otherwise, leave blank.
 
